@@ -4,7 +4,7 @@
 ;; Author: J.D. Smith <jdtsmith+elpa@gmail.com>
 ;; Homepage: https://github.com/jdtsmith/indent-bars
 ;; Package-Requires: ((emacs "27.1") (compat "29.1"))
-;; Version: 0.7.5
+;; Version: 0.7.6
 ;; Keywords: convenience
 
 ;; indent-bars is free software: you can redistribute it and/or
@@ -61,6 +61,7 @@
 (require 'timer)
 (require 'outline)
 (require 'font-lock)
+(require 'jit-lock)
 (require 'face-remap)
 (require 'cus-edit)
 (require 'compat)
@@ -518,20 +519,20 @@ and used to sort the list numerically.  A list of the foreground
 color of the matching, sorted faces will be returned, unless
 FACE-BG is non-nil, in which case the background color is
 returned."
-  (mapcar (lambda (x) (funcall (if face-bg #'face-background #'face-foreground)
-			       (cdr x) nil 'default))
+  (mapcar (lambda (x)
+	    (funcall (if face-bg #'face-background #'face-foreground)
+		     (cdr x) nil 'default))
           (seq-sort-by #'car
-		       (lambda (a b) (cond
-				      ((not (numberp b)) t)
-				      ((not (numberp a)) nil)
-				      (t (< a b))))
-		       (mapcan
-			(lambda (x)
-			  (let ((n (symbol-name x)))
-			    (if (string-match regexp n)
-                                (list (cons (string-to-number (match-string 1 n))
-					    x)))))
-			(face-list)))))
+	   (lambda (a b) (cond
+			  ((not (numberp b)) t)
+			  ((not (numberp a)) nil)
+			  (t (< a b))))
+	   (mapcan
+	    (lambda (x)
+	      (let ((n (symbol-name x)))
+		(when (and (string-match regexp n) (match-string 1 n))
+                  (list (cons (string-to-number (match-string 1 n)) x)))))
+	    (face-list)))))
 
 (defun indent-bars--unpack-palette (palette)
   "Process a face or color-based PALETTE."
@@ -1148,7 +1149,7 @@ not indicated, even if they otherwise would be."
     nil))
 
 ;;;; jit-lock support
-(defvar indent-bars--orig-fontify-region nil)
+(defvar-local indent-bars--orig-fontify-region nil)
 (defun indent-bars--extend-region (start end)
   "Extend the region START..END.
 If `indent-bars-display-on-blank-lines' is non-nil, this extends
@@ -1673,8 +1674,9 @@ Adapted from `highlight-indentation-mode'."
   (with-silent-modifications
     (remove-text-properties (point-min) (point-max) '(indent-bars-display nil)))
 
-  (font-lock-flush)
-  (font-lock-ensure)
+  (jit-lock-refontify)
+  ;; (font-lock-flush)
+  ;; (font-lock-ensure)
 
   (setq indent-bars--current-depth 0)
   (remove-hook 'text-scale-mode-hook #'indent-bars--update-all-stipples t)
